@@ -1,7 +1,7 @@
 setVectorSeed <- function(vseed)
 {
     RNGkind("Mersenne-Twister")
-    stopifnot(.Random.seed[1] %% 100 == 3)
+    stopifnot(length(.Random.seed) == 626)
     stopifnot(.Random.seed[2] == 624)
     .Random.seed[3:626] <<- generateInitialization(vseed, 624)
     invisible(NULL)
@@ -14,12 +14,12 @@ generateInitialization <- function(vseed, m)
 	vseed <- c(vseed, length(vseed))
     s <- numeric(8*ceiling(length(vseed)/8))
     s[seq.int(along.with=vseed)] <- vseed
-    mm <- 4*ceiling(m/4)
+    m4 <- 4*ceiling(m/4)
     .C("getVectorSeed",
         length(s),
         as.double(s),
-        as.integer(mm),
-        out=integer(mm),
+        as.integer(m4),
+        out=integer(m4),
         PACKAGE="rngSetSeed")$out[seq.int(length.out=m)]
 }
 
